<template>
  <el-dialog v-dialogDrag
             :title="title"
             :visible.sync="visible"
             :width="width"
             :fullscreen="fullscreen"
             :append-to-body="true"
             top="0"
             class="avue-dialog"
             :destroy-on-close="true"
             @close="dialogClose">
    <basic-form ref="formRef" v-if="paramVOS.form"
                :key="'dialog-'+paramVOS.form"
                :span="span"
                :style="fullscreen?'':'height:'+height"
                :isEdit="true"
                :formItems="formItems"
                :formData="form">
    </basic-form>
    <ui-view ref="uiViewRef" v-else-if="paramVOS.context"
             :key="'AddEditDialog-'+type"
             :style="fullscreen?'':'height:'+height"
             :btmType="paramVOS.type"
             :context="paramVOS.context"
             :inDialog="true"
             :canEdit="true"
             :sourceData="sourceData"
             :dataStore="dataStore"
             :paramVOS="paramVOS"
    ></ui-view>
    <div v-if="showSave" class="dialog-footer avue-dialog__footer">
      <el-button type="primary" plain size="small" @click="saveHandler">保 存</el-button>
      <el-button size="small" @click="dialogClose">取 消</el-button>
      <el-button size="small" @click="resetValue" v-if="paramVOS.form">重 置</el-button>
    </div>
  </el-dialog>
</template>

<script>
import uiView from "@/views/base/UIContentViewerInDialog"
import {getFormDefineById,dataForm} from "@/api/base/ui";
import {addSave,editSave} from "@/api/base/actions"
import {validatenull} from "@/util/validate"

export default {
  name: "AddEditDialog",
  components:{uiView},
  props: {
    sourceData: {
      //所属区域的上一区域选中数据
      type: Object,
      default: {}
    },
    dataStore: {
      //弹窗时按钮所属区域选中数据
      type: Array,
      default: []
    },
    paramVOS: {
      type: Object,
      default: {}
    }
  },
  data(){
    return {
      type:"add",
      visible:false,
      showSave:this.paramVOS.customBtn || true,
      span:12,
      formItems:[],
      form:{}
    }
  },
  computed:{
    title(){
      return this.paramVOS.title || (this.type=='add'?'添加':'修改')
    },
    width() {
      if (!validatenull(this.paramVOS.width)) {
        if (this.paramVOS.width.includes("px") || this.paramVOS.width.includes("%")) {
          return this.paramVOS.width;
        } else {
          return this.paramVOS.width + "px";
        }
      } else {
        return "60%";
      }
    },
    height(){
      if (!validatenull(this.paramVOS.height)) {
        if (this.paramVOS.height.includes("px") || this.paramVOS.height.includes("%")) {
          return this.paramVOS.height;
        } else {
          return this.paramVOS.height + "px";
        }
      } else {
        return "auto"
      }
    },
    fullscreen(){
      if(this.paramVOS.width || this.paramVOS.height){
        return false;
      }else if(this.paramVOS.form){
        return false;
      }
      return true;
    }
  },
  created() {
  },
  watch: {
    sourceData: {
      handler(val) {
        if (this.paramVOS.form) {
          this.onLoad();
        }
      },
      deep: true,
      immediate: true
    },
  },
  methods: {
    dialogClose() {
      this.visible = false;
    },
    onLoad: function () {
      if (Object.keys(this.sourceData).length > 0) {
        this.loading = true;
        getFormDefineById(this.paramVOS.type,this.paramVOS.form).then(result => {
          this.formItems=result.data.obj.items;
          this.span=result.data.obj.columnOneRow?(24/result.data.obj.columnOneRow) : 12;

          if (this.paramVOS.initvalue) {
            this.form=this.paramVOS.initvalue;
          }
          if(this.type=="edit") {
            //加载表单数据
            let sourceDataMap = {};
            for (let i in this.sourceData) {
              const item = this.sourceData[i]
              if (item.constructor === Object) return;
              sourceDataMap['sourceData["' + i + '"]'] = item;
            }
            dataForm(Object.assign({
              btmname: this.paramVOS.type,
              formDefineId: this.paramVOS.form,
              oid: this.dataStore[0].oid
            }, sourceDataMap), this.paramVOS.getdataurl, this.paramVOS.getdatamethod).then(res => {
              this.form = res.data.obj;
              this.loading = false;
            }).catch(error => {
              this.$message.error(error);
              this.loading = false;
            })
          }
        }).catch(error => {
          this.$message.error(error);
          this.loading = false;
        });

      }
    },
    saveHandler() {
      if(this.paramVOS.form){
        this.$refs.formRef.validate((valid, done) => {
          if (valid) {
            this.saveValue(this.form)
          } else {

          }
        });
      }else{
        //this.$refs.uiViewRef.
        debugger;
        if(this.saveCallback){
          this.saveCallback({});
        }
      }

    },
    saveValue(savedata){
      if(this.type=="add"){
        addSave(savedata,this.paramVOS.url,this.paramVOS.method).then(() => {
          this.$message({
            type: "success",
            message: "保存成功!"
          });
          if(this.saveCallback){
            this.saveCallback(savedata);
          }
          this.dialogClose();
        }).error((e) => {
          this.$message.error(e||"保存失败")
        });
      }else{
        editSave(savedata,this.paramVOS.url,this.paramVOS.method).then(() => {
          this.$message({
            type: "success",
            message: "修改成功!"
          });
          if(this.saveCallback){
            this.saveCallback(savedata);
          }
          this.dialogClose();
        }).error((e) => {
          this.$message.error(e||"修改失败")
        });
      }
    },
    resetValue() {
      if (this.paramVOS.form) {
        this.$refs.formRef.resetFields();
      }
    }
  }
}
</script>

<style scoped>

</style>
